from setuptools import setup

setup(name='hjw-distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author = 'Jingwen Huang',
      author_email = 'jingwen.h@yahoo.com',
      packages=['hjw-distributions'],
      zip_safe=False)
